pychemia.code.abinit.tests package
==================================

.. automodule:: pychemia.code.abinit.tests
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

pychemia.code.abinit.tests.test_abinit module
---------------------------------------------

.. automodule:: pychemia.code.abinit.tests.test_abinit
    :members:
    :undoc-members:
    :show-inheritance:


